<?php

namespace LTK\Foundation\Customize;

use WP_Customize_Manager;

class Customizer {

	/**
	 * Inserts Customizer settings into WordPress
	 *
	 * @param WP_Customize_Manager $wp_customize Cuztomizer object
	 */
	static public function register(WP_Customize_Manager $wp_customize) {

		/* Default settings */

		$wp_customize->get_setting('blogname')->transport = 'postMessage';
      	$wp_customize->get_setting('blogdescription')->transport = 'postMessage';
      	$wp_customize->get_setting('header_textcolor')->transport = 'postMessage';

		/* SECTION: Structure */

		$wp_customize->add_section('ltk-foundation-section-structure', [
			'title' => __('Page layout', 'ltk-foundation'),
			'description' => __('Settings that affect how elements are organized within the website.', 'ltk-foundation'),
			'priority' => 90
		]);

		/* SETTING: Structure > Layout */

		$wp_customize->add_setting('ltk-foundation-setting-layout', [
			'default' => 'container',
			'sanitize_callback' => 'LTK\Foundation\Customize\Customizer::sanitizeSettingLayout'
		]);

		$wp_customize->add_control('ltk-foundation-setting-layout', [
			'type' => 'select',
			'label' => __('Layout mode', 'ltk-foundation'),
			'section' => 'ltk-foundation-section-structure',
			'choices' => [
				'container' => __('Inside a container', 'ltk-foundation'),
				'full-width' => __('Full width', 'ltk-foundation')
			],
		]);

	}

	/**
	 * Sanitize layout setting
	 *
	 * Possible values are 'container' and 'full-width', if other is sent, this
	 * function will just return 'container' instead.
	 *
	 * @param string $input Value of the layout setting
	 *
	 * @return string Sanitized value
	 */
	static public function sanitizeSettingLayout($input) {

		if (! in_array($input, ['container', 'full-width'])) {
			return 'container';
		}

		return $input;

	}

	/**
	 * Inserts scripts into theme customizer to allow instant modification
	 */
	static public function registerPreview() {
		wp_enqueue_script('ltk-theme-customizer',
			get_template_directory_uri() . '/assets/js/theme-customizer.min.js',
			['jquery', 'customize-preview'], '', true
		);
	}

	/**
	 * WordPress default settings: header, logo, colors...
	 */
	static public function defaultSettings() {
		
		$header_image = get_theme_mod('header_image', false);
		if ($header_image && $header_image != 'remove-header') { ?>
			<style>
				#site-header {
					background: url("<?php echo esc_url($header_image); ?>") center center no-repeat;
					background-size: cover;
					<?php if (get_theme_mod('ltk-foundation-setting-layout', 'container') == 'container'): ?>
						padding: 15px;
					<?php endif; ?>
				}
			</style>
		<?php }
		
		$header_textcolor = get_header_textcolor();
		if ($header_textcolor != '' && $header_textcolor != 'blank') { ?>
			<style>
				#site-description {
					color: #<?php echo $header_textcolor; ?>;
				}
			</style>
		<?php }
		
	}
	
}
