<?php

namespace LTK\Foundation\View;

class Post {

	/**
	 * Returns a link to the author's page including the number of published
	 * posts
	 *
	 * @return string HTML of the link
	 */
	static public function getAuthorArticlesLink() {

		$count = get_the_author_posts();

		if ($count == 0) {
			return '<span>' . __('This author has no articles yet.', 'ltk-foundation') . '</span>';
		}

		$text = sprintf(_n(
			'%s article from this author',
			'%s articles from this author',
			$count, 'ltk-foundation'
		), $count);

		$url = get_author_posts_url(get_the_author_meta('ID'));

		return "<a href=\"$url\" rel=\"nofollow\">$text</a>";

	}

	/**
	 * Get a link to current author's website
	 *
	 * @return string|null Author link if any, null otherwise
	 * @since 1.2.0
	 */
	static public function getAuthorWebsiteLink() {

		$url = esc_url(get_the_author_meta('user_url'));

		if (! empty($url)) {
			$text = esc_html(parse_url($url, PHP_URL_HOST));
			return "<a href=\"$url\" rel=\"nofollow\">$text</a>";
		} else {
			return '';
		}

	}

	/**
	 * Adds a Font-Awesome lock icon to password protected and private posts
	 *
	 * @param string $title
	 * @return string
	 */
	static public function passwordProtectedPostIcon($title) {
		return '<i class="fa fa-lock"></i> %s';
	}

	/**
	 * Set up new defaults for the post pagination
	 *
	 * @param array $args Arguments passed to the post pagination function
	 *
	 * @return array New arguments for the pagination function
	 */
	static public function paginationArguments($args) {
		return [
			'before' => '<ul class="pagination">',
			'after' => '</ul>',
			'link_before' => '',
			'link_after' => '',
			'next_or_number' => 'number',
			'separator'  => '',
			'nextpagelink' => __('Next page', 'ltk-foundation') . ' &rarr;',
			'previouspagelink' => '&larr; ' . __('Previous page', 'ltk-foundation'),
			'pagelink' => '%',
			'echo' => 1
		];
	}

	/**
	 * Wrap post pagination into a div
	 *
	 * @param string $html Pagination generated html
	 *
	 * @return string Pagination HTML, wrapped
	 */
	static public function paginationFilterPages($html) {

		if (empty($html)) {
			return;
		}

		$output = '<div class="item-pagination">';
			$output .= '<p class="pull-left">' . __('Article pages:', 'ltk-foundation') . '</p>';
			$output .= $html;
		$output .= '</div>';

		return $output;

	}

	/**
	 * Wrap pagination links into <li>
	 *
	 * @param string $item Pagination link
	 *
	 * @return string Pagination link, wrapped into <li> and <a> if that's the
	 * active page
	 */
	static public function paginationFilterPagesLink($item) {

		$isCurrentPage = false;
		if (is_numeric($item)) {
			$isCurrentPage = true;
			$item = "<a href>$item</a>";
		}

		if ($isCurrentPage) {
			return "<li class=\"active\">$item</li>";
		} else {
			return "<li>$item</li>";
		}

	}

}
